import { p as parser } from './liquidsoap-826221b5.js';
import { LRLanguage, LanguageSupport } from '@codemirror/language';
import { styleTags, tags } from '@lezer/highlight';
import '@lezer/lr';

const LiquidsoapLanguage = LRLanguage.define({
    parser: parser.configure({
        props: [
            styleTags({
                Var: tags.variableName,
                Type: tags.typeName,
                Bool: tags.bool,
                String: tags.string,
                Method: tags.propertyName,
                LabeledArgument: tags.labelName,
                Integer: tags.integer,
                Float: tags.float,
                Regexp: tags.regexp,
                EscapedChar: tags.escape,
                Op: tags.operatorKeyword,
                LineComment: tags.lineComment,
                BlockComment: tags.blockComment,
                ControlKeyword: tags.controlKeyword,
                Keyword: tags.keyword,
                DefinitionKeyword: tags.definitionKeyword,
                LogicOperator: tags.logicOperator,
                CompareOperator: tags.compareOperator,
                ArithmeticOperator: tags.arithmeticOperator,
                DerefOp: tags.derefOperator,
                UpdateOp: tags.updateOperator,
                "( )": tags.paren,
                "[ ]": tags.bracket,
            }),
        ],
    }),
    languageData: {
        commentTokens: { line: ";" },
    },
});
function liquidsoap() {
    return new LanguageSupport(LiquidsoapLanguage);
}

export { LiquidsoapLanguage, liquidsoap };
